%global nhgamedir /usr/games/nethack-3.4.3
%global nhdatadir /var/games/nethack

Name:           nethack
Version:        3.4.3
Release:        %mkrel 1
Summary:        A rogue-like single player dungeon exploration game

Group:          Games/Arcade
License:        NGPL
URL:            http://nethack.org
Source0:        http://downloads.sourceforge.net/%{name}-%{version}.tar.xz
Patch0:         %{name}-%{version}-makefile.patch
Patch1:         %{name}-%{version}-config.patch
Patch2:         %{name}-%{version}-x11.patch
Patch3:         %{name}-%{version}-guidebook.patch
BuildRoot:      %{_tmppath}/%{name}-%{version}-%{release}-buildroot
BuildRequires:  ncurses-devel
BuildRequires:  bison, flex, desktop-file-utils
BuildRequires:  bdftopcf libx11-devel libxaw-devel 
BuildRequires:  libxmu-devel libxpm-devel libxt-devel
BuildRequires:  fontconfig-devel libxext-devel




%description
NetHack is a single player dungeon exploration game that runs on a
wide variety of computer systems, with a variety of graphical and text
interfaces all using the same game engine.

Unlike many other Dungeons & Dragons-inspired games, the emphasis in
NetHack is on discovering the detail of the dungeon and not simply
killing everything in sight - in fact, killing everything in sight is
a good way to die quickly.

Each game presents a different landscape - the random number generator
provides an essentially unlimited number of variations of the dungeon
and its denizens to be discovered by the player in one of a number of
characters: you can pick your race, your role, and your gender.


%prep
%setup -q
%patch0 -b .makefile
%patch1 -b .config
%patch2 -b .x11
%patch3 -b .guidebook
(source sys/unix/setup.sh)

# Set our paths
%{__sed} -i -e "s:^\(HACKDIR=\).*:\1%{nhgamedir}:" sys/unix/nethack.sh
%{__sed} -i -e "s:PCLOS_CONFDIR:%{nhgamedir}:" sys/unix/nethack.sh
%{__sed} -i -e "s:PCLOS_STATEDIR:%{nhdatadir}:" include/unixconf.h
%{__sed} -i -e "s:PCLOS_HACKDIR:%{nhgamedir}:" include/config.h
%{__sed} -i -e "s:/usr/games/lib/nethackdir:%{nhgamedir}:" \
        doc/nethack.6 doc/nethack.txt doc/recover.6 doc/recover.txt

# Point the linker in the right direction
%{__sed} -i -e "s:-L/usr/X11R6/lib:-L/usr/X11R6/%{_lib}:" \
        src/Makefile util/Makefile


%build
make all


%install
rm -rf $RPM_BUILD_ROOT
%makeinstall \
        GAMEDIR=$RPM_BUILD_ROOT%{nhgamedir} \
        VARDIR=$RPM_BUILD_ROOT%{nhdatadir} \
        SHELLDIR=$RPM_BUILD_ROOT%{_bindir} \
        CHOWN=/bin/true \
        CHGRP=/bin/true

rm -rf $RPM_BUILD_ROOT%{nhgamedir}/save
mv $RPM_BUILD_ROOT%{nhgamedir}/recover $RPM_BUILD_ROOT%{_bindir}/nethack-recover

install -d -m 0755 $RPM_BUILD_ROOT%{_mandir}/man6
make -C doc MANDIR=$RPM_BUILD_ROOT%{_mandir}/man6 manpages

install -D -p -m 0644 win/X11/nh_icon.xpm \
        $RPM_BUILD_ROOT%{_datadir}/pixmaps/nethack.png


mkdir -p $RPM_BUILD_ROOT%{_datadir}/applications
cat > $RPM_BUILD_ROOT%{_datadir}/applications/%{name}.desktop << EOF
[Desktop Entry]
Encoding=UTF-8
Name=NetHack
Comment=Single player dungeon exploration game
Exec=nethack
Icon=nethack
Terminal=true
Type=Application
StartupNotify=true
Categories=Game;RolePlaying;X-MandrivaLinux-MoreApplications-Games-Other;
EOF


# Install the fonts for the X11 interface
cd win/X11
bdftopcf -o nh10.pcf nh10.bdf
bdftopcf -o ibm.pcf ibm.bdf
mkdir -p $RPM_BUILD_ROOT/%_datadir/fonts/%name
install -m 0755 -d $RPM_BUILD_ROOT/%_datadir/fonts/%name
install -m 0644 -p *.pcf $RPM_BUILD_ROOT/%_datadir/fonts/%name

%{__sed} -i -e 's:^!\(NetHack.tile_file.*\):\1:' \
        $RPM_BUILD_ROOT%{nhgamedir}/NetHack.ad

%post 
ln -s /usr/share/fonts/nethack /etc/X11/fontpath.d/nethack


%preun 
rm -rf /etc/X11/fontpath.d/nethack
rm -rf /usr/share/fonts/nethack



%clean
rm -rf $RPM_BUILD_ROOT


%files
%defattr(-,root,root,-)
%doc doc/*.txt README dat/license dat/history
%doc dat/opthelp dat/wizhelp
%{_mandir}/man6/*
%{_datadir}/pixmaps/nethack.png
%{_datadir}/applications/nethack.desktop
%{_datadir}/fonts/%name
%{nhgamedir}/nhdat
%{_bindir}/nethack
%{_bindir}/nethack-recover
%{nhgamedir}
%defattr(0664,root,games)
%config(noreplace) %{nhdatadir}/record
%config(noreplace) %{nhdatadir}/perm
%config(noreplace) %{nhdatadir}/logfile
%attr(0775,root,games) %dir %{nhdatadir}
%attr(0775,root,games) %dir %{nhdatadir}/save
%attr(2755,root,games) %{nhgamedir}/nethack

%changelog
* Wed Apr 12 2013 Ken <lxgator at gmail dot com> 3.4.3-1pclos2013
- Initial pkg - import Fedora spec

